The code for the Scallop baselines is adapted from [the official implementation](https://github.com/scallop-lang/scallop/blob/07d884308fecc2f0c1d37d3186309987dd52c938/experiments/mnist/sum_double_2.py).

First install scallopy as described in the [Scallop documentation](https://www.scallop-lang.org/download.html).
Then run:
```bash
python experiments/mnist_addition/scallop/1_digit.py
```